@@ -15,7 +15,7 @@ Here's a table of user-friendly aliases and the backend classes they refer to:
    * - Alias
      - Class or function name
    * - P
-     - :func:`probcalc.distributions.calculate_probability`
+     - :class:`probcalc.distributions.ProbabilityCalculator`
    * - B
      - :class:`probcalc.distributions.BinomialDistribution`
    * - Po
@@ -25,10 +25,10 @@ Here's a table of user-friendly aliases and the backend classes they refer to:
 from . import distributions, utility
 from .distributions import NonsenseError
 
-P = distributions.calculate_probability
+P = distributions.ProbabilityCalculator()
 B = distributions.BinomialDistribution
 Po = distributions.PoissonDistribution
 
 __all__ = ['P', 'B', 'Po', 'NonsenseError', 'distributions', 'utility']
 
-__version__ = '0.2.4'
+__version__ = '0.2.5'
