@@ -92,6 +92,9 @@ class Distribution(abc.ABC):
        ``NotImplemented`` if the user tries to compare a discrete distribution with a float.
     """
 
+    negate_probability: bool
+    """This attribute is a flag set by :meth:`__ne__` and used by :meth:`calculate` for the ``!=`` operator."""
+
     def __init__(self, *, accepts_floats: bool):
         """Create a :class:`Distribution` object with natural bounds and one flag.
 
@@ -99,10 +102,12 @@ class Distribution(abc.ABC):
         """
         self.bounds = Bounds()
         self.accepts_floats = accepts_floats
+        self.negate_probability = False
 
-    def reset_bounds(self) -> None:
-        """Reset the bounds of the distribution to be the default, natural bounds (None)."""
+    def reset(self) -> None:
+        """Reset the bounds of the distribution to be the default, and reset :attr:`negate_probability` flag."""
         self.bounds = Bounds()
+        self.negate_probability = False
 
     @abc.abstractmethod
     def __repr__(self) -> str:
@@ -128,6 +133,26 @@ class Distribution(abc.ABC):
         self.bounds.lower = (other, True)
         return self
 
+    def __ne__(self, other):
+        """Set the upper and lower bounds to ``other``, if possible, and set :attr:`negate_probability`.
+
+        See :meth:`__eq__`.
+
+        :raises NonsenseError: If the user has tried to mix inequality and equality comparison
+        """
+        if not (isinstance(other, int) or (self.accepts_floats and isinstance(other, float))):
+            return NotImplemented
+
+        # If the bounds are already mutated, then we've mixed inequality and equality
+        if self.bounds != Bounds():
+            raise NonsenseError('Cannot have inequality and equality mixed together')
+
+        self.bounds.upper = (other, True)
+        self.bounds.lower = (other, True)
+
+        self.negate_probability = True
+        return self
+
     def __lt__(self, other):
         """Set the upper bound and don't include this value."""
         if not (isinstance(other, int) or (self.accepts_floats and isinstance(other, float))):
@@ -195,6 +220,9 @@ class Distribution(abc.ABC):
         if probability < 0:
             raise NonsenseError("This inequality doesn't make sense")
 
+        if self.negate_probability:
+            probability = 1 - probability
+
         return round_sig_fig(probability, 10)
 
     @abc.abstractmethod
@@ -388,32 +416,39 @@ class PoissonDistribution(Distribution):
             sum(self.pmf(x) for x in range(number + 1))  # type: ignore[misc]
 
 
-def calculate_probability(distribution: Distribution) -> float:
-    """Return the probability of a random variable from this distribution taking on a value within its bounds.
+class ProbabilityCalculator:
+    """This class only exists to give the probability calculator a nice repr."""
 
-    This function is just a convenient wrapper around :meth:`Distribution.calculate`.
+    def __repr__(self) -> str:
+        """Return a very simple repr of the calculator."""
+        return 'P'
 
-    .. note::
-       This function calls :meth:`Distribution.reset_bounds`, but the
-       class method doesn't on its own. Using the class method multiple times with different inputs can
-       result in undefined behaviour. Use this function for all interactive use.
+    def __call__(self, distribution: Distribution) -> float:
+        """Return the probability of a random variable from this distribution taking on a value within its bounds.
 
-    This function gets exported as ``P`` by ``__init__.py``, which lets the user do things like:
+        This function is just a convenient wrapper around :meth:`Distribution.calculate`.
 
-    :Example:
+        .. note::
+           This function calls :meth:`Distribution.reset`, but :meth:`Distribution.calculate`
+           doesn't on its own. Using the class method multiple times with different inputs can
+           result in undefined behaviour. Use this wrapper for all interactive use.
 
-    >>> from probcalc import P, B
-    >>> X = B(20, 0.5)
-    >>> P(X > 6)
-    0.9423408508
-    >>> P(4 < X <= 12)
-    0.8625030518
+        This function gets exported as ``P`` by ``__init__.py``, which lets the user do things like:
 
-    :param Distribution distribution: The probability distribution that we're using to calculate the value
-    :returns float: The calculated probability
+        :Example:
 
-    :raises NonsenseError: If the bounds of the distribution are invalid
-    """
-    probability = distribution.calculate(strict=True)
-    distribution.reset_bounds()
-    return probability
+        >>> from probcalc import P, B
+        >>> X = B(20, 0.5)
+        >>> P(X > 6)
+        0.9423408508
+        >>> P(4 < X <= 12)
+        0.8625030518
+
+        :param Distribution distribution: The probability distribution that we're using to calculate the value
+        :returns float: The calculated probability
+
+        :raises NonsenseError: If the bounds of the distribution are invalid
+        """
+        probability = distribution.calculate(strict=True)
+        distribution.reset()
+        return probability
